@@ -3,10 +3,9 @@ import sys
 import time
 from PySide.QtCore import *
 from PySide.QtGui import *
-from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5ListPickSelector
 
 # Some global variables
-Cps2GuiVersion = "0.0.1-3"
+Cps2GuiVersion = "0.0.1-4"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -78,9 +77,10 @@ class Ui_MainWindow(QMainWindow):
 	backgroundLabel.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
       	self.setCentralWidget(backgroundLabel)
 	# Get Gametitles from rom_path
-	ListCmd = "cd '" + self.gui_opts["rom_path"] + "';ls -1 *.zip" 
+	ListCmd = "cd '" + self.gui_opts["rom_path"] + "';ls -1 *.zip 2>/dev/null" 
 	fin,fout = os.popen4(ListCmd)
 	romList = fout.read()
+	fin.close()
 	romList = romList.strip().replace('.zip','')
 	romList = romList.split('\n')
         f = open(Cps2_GameFile)
@@ -91,8 +91,6 @@ class Ui_MainWindow(QMainWindow):
 			worklist.append([Gamelist[0],Gamelist[1]])
         f.close()
 	worklist.sort(key=lambda x:x[1])
-	if not romList:
-		worklist = ["","No roms found!"]
 
         self.combo = QComboBox(self)
         self.combo.setStyleSheet( \
@@ -103,23 +101,16 @@ class Ui_MainWindow(QMainWindow):
 	 }" )
 	self.combo.setGeometry(QRect(20, 180, 750, 60))
 	maxLength=63
+	if not worklist:
+		worklist = [["NOROMS","No roms found!"]]
 	for Game in worklist:
 		space=""
 		spacecount=maxLength-len(Game[1])
 		for x in range(0,spacecount):
 			space=space+" "
-        	self.combo.addItem(space+Game[1])
+       		self.combo.addItem(space+Game[1])
 	self.GameFile=[[t[0]] for t in worklist]
 
-#	self.combo.setEditable(True)
-#	self.combo.lineEdit().setAlignment(Qt.AlignCenter)  
-#	self.combo.lineEdit().setReadOnly(True)
-#	self.combo.lineEdit().setAlignment(Qt.AlignCenter)  
-#	for x in range(0,self.combo.count()):
-#		self.combo.setItemData(x, Qt.AlignCenter, Qt.TextAlignmentRole)
-#	self.combo.setEditable(False)
-
-
 	# Define menubar
 	aboutAction = QAction( '&About', self)
         aboutAction.triggered.connect(self.slotAbout)
@@ -179,14 +170,14 @@ class Ui_MainWindow(QMainWindow):
 	ALL_OPTS = ALL_OPTS + "--samplerate " + self.gui_opts["samplerate"] + " "
 	ALL_OPTS = ALL_OPTS + "--" + self.gui_opts["rescaling"] + " "
 
-	if self.gameFile:
+	if (self.gameFile) and ("NOROMS" not in self.gameFile):
 		# we can't do multiple commands in startDetached
 		os.chdir(self.gui_opts["rom_path"])
 		QProcess.startDetached(self.gui_opts["exec_path"] + "/cps2emu "+ALL_OPTS+ " " +self.gameFile[0] + ".zip")
 
-	if (self.gui_opts["exit_after_launch"] == "true"):
-		time.sleep(5)
-		os._exit(0)
+		if (self.gui_opts["exit_after_launch"] == "true"):
+			time.sleep(5)
+			os._exit(0)
 
     def slotAbout(self):
         a = AboutWindow(self)
@@ -1218,7 +1209,7 @@ class pathWindow(QDialog):
 
     def on_rom_homebutton_clicked(self):
 	global RomPath
-	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/home', QFileDialog.ShowDirsOnly)
+	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/home')
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
@@ -1226,7 +1217,7 @@ class pathWindow(QDialog):
 
     def on_rom_rootbutton_clicked(self):
 	global RomPath
-	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/media', QFileDialog.ShowDirsOnly)
+	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/media')
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
